#pragma subtitle ("CW MQM miscellaneous definitions")
#pragma page ()

       /*----------------------------------------------------+
       | CWMQM.H                                             |
       | CW MQM Miscellaneous definitions.                   |
       |                                                     |
       | This includes general definitions and control block |
       | structures for CW MQM.                              |
       ------------------------------------------------------|
       | CHANGE HISTORY:                                     |
       *-----------------------------------------------------+
       | Date       Change-id   Produced     SCR number.     |
       | yyyymmdd               Version.                     |
       |                        rr.ss.uu                     |
       | Reason                                              |
       |-----------------------------------------------------|
       | 19980601   R. Lacroix  01.00.00                     |
       | Birth.                                              |
       |                                                     |
       +----------------------------------------------------*/
#ifndef __CWMQMH
   #define __CWMQMH 1 /* Indicate that this file has been included. */



typedef char   QUEUE_NAME [ 48 ];


typedef enum  { OFF, ON } flag_type;


/*----------------------------------------------------+
| CW_RC_T - this enumerated list contains the         |
|            possible values for a general CW return  |
|            code.                                    |
+----------------------------------------------------*/


typedef enum CW_RC_E
{
        CW_RC_OK          = 0,
        CW_RC_WARNING     = 4,
        CW_RC_FAILED      = 8,
        CW_RC_SEVERE      = 16,
        CW_RC_TIMEOUT     = 20,
        CW_RC_MAX_BACKOUT = 24,
        CW_RC_QUIESCING   = 28,
        CW_RC_MAX         = 0x7FFFFFFF
} CW_RC_T;



/*----------------------------------------------------+
|                                                     |
|                                                     |
|                                                     |
+-----------------------------------------------------*/


typedef struct CW_REPLYTO_S
{
        QUEUE_NAME     QueueMgrName;
        QUEUE_NAME     QueueName;
} CW_REPLYTO_T;

/*----------------------------------------------------+
| CW_ConnectToMqm - establish a connection with the   |
|                   local MQM.                        |
+----------------------------------------------------*/

static CW_RC_T CW_ConnectToMqm( QUEUE_NAME  QueueMgrName );

/*----------------------------------------------------+
| CW_DisconnectFromMqm - terminate an existing        |
|                        connection with local MQM.   |
+----------------------------------------------------*/

static CW_RC_T CW_DisconnectFromMqm( );

/*-----------------------------------------------------+
| CW_OpenMqmQueue - open a named MQM queue.            |
+-----------------------------------------------------*/

static CW_RC_T CW_OpenMqmQueue( QUEUE_NAME     QueueMgrName,
                                QUEUE_NAME     QueueName,
                                QUEUE_NAME     DynamicQueueName,
                                MQHOBJ        *QueueHandlePtr,
                                MQLONG         OpenOptions );

/*----------------------------------------------------+
| CW_CloseMqmQueue - close an MQM queue.              |
+----------------------------------------------------*/

static CW_RC_T CW_CloseMqmQueue( MQHOBJ     *QueueHandlePtr );

/*----------------------------------------------------+
| CW_GetMqmMessage - get the first message from the   |
|                    local MQM queue.                 |
+----------------------------------------------------*/

static CW_RC_T CW_GetMqmMessage( MQHOBJ        QueueHandle,
                                 void         *ReceiveMqmBufferPtr,
                                 int           ReceiveMqmBufferSize,
                                 int           MqmTimeOut,
                                 MQLONG       *ReturnedDataLength,
                                 CW_REPLYTO_T *ReplyTo);

/*-------------------------------------------------------+
| CW_SendMqmMessage - put an MQM message onto the queue  |
|                     associated with the passed handle. |
+-------------------------------------------------------*/

static CW_RC_T CW_SendMqmMessage( MQHOBJ         QueueHandle,
                                  void          *SendMqmBufferPtr,
                                  int            SendMqmBufferSize,
                                  QUEUE_NAME     ReplyToQueueName);

/*----------------------------------------------------+
| CW_SendOneMqmMessage - Open, Put a message and      |
|                        Close the queue associated   |
|                        with the passed name.        |
+----------------------------------------------------*/

static CW_RC_T CW_SendOneMqmMessage( QUEUE_NAME   QMgrName,
                                     QUEUE_NAME   QueueName,
                                     QUEUE_NAME   ReplyToQMgrName,
                                     QUEUE_NAME   ReplyToQueueName,
                                     void        *SendMqmBufferPtr,
                                     int          SendMqmBufferSize);

#endif
